macro_rules! hot_inline {
() => { ... };
}Expand description
Inlining hints for hot functions
Functions marked with HOT_INLINE should be aggressively inlined. These are called in tight loops and benefit from inlining.
macro_rules! hot_inline {
() => { ... };
}Inlining hints for hot functions
Functions marked with HOT_INLINE should be aggressively inlined. These are called in tight loops and benefit from inlining.