Module dead_code_elimination

Module dead_code_elimination 

Dead code elimination markers

Functions/constants marked with this can be eliminated if unused.

Functions

mark_unused
Mark code for dead code elimination analysis This is a marker function - the compiler can eliminate unused paths
unlikely
Hint to compiler that branch is unlikely (dead code elimination)