Display

Trait Display 

1.36.0 · Source
pub trait Display {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
Format trait for an empty format, {}.

Implementing this trait for a type will automatically implement the ToString trait for the type, allowing the usage of the .to_string() method. Prefer implementing the Display trait for a type, rather than ToString.

Display is similar to Debug, but Display is for user-facing output, and so cannot be derived.

For more information on formatters, see the module-level documentation.

Completeness and parseability

Display for a type might not necessarily be a lossless or complete representation of the type. It may omit internal state, precision, or other information the type does not consider important for user-facing output, as determined by the type. As such, the output of Display might not be possible to parse, and even if it is, the result of parsing might not exactly match the original value.

However, if a type has a lossless Display implementation whose output is meant to be conveniently machine-parseable and not just meant for human consumption, then the type may wish to accept the same format in FromStr, and document that usage. Having both Display and FromStr implementations where the result of Display cannot be parsed with FromStr may surprise users.

Internationalization

Because a type can only have one Display implementation, it is often preferable to only implement Display when there is a single most “obvious” way that values can be formatted as text. This could mean formatting according to the “invariant” culture and “undefined” locale, or it could mean that the type display is designed for a specific culture/locale, such as developer logs.

If not all values have a justifiably canonical textual format or if you want to support alternative formats not covered by the standard set of possible formatting traits, the most flexible approach is display adapters: methods like str::escape_default or Path::display which create a wrapper implementing Display to output the specific display format.

Examples

Implementing Display on a type:

use std::fmt;

struct Point {
    x: i32,
    y: i32,
}

impl fmt::Display for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.x, self.y)
    }
}

let origin = Point { x: 0, y: 0 };

assert_eq!(format!("The origin is: {origin}"), "The origin is: (0, 0)");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Examples
use std::fmt;

struct Position {
    longitude: f32,
    latitude: f32,
}

impl fmt::Display for Position {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.longitude, self.latitude)
    }
}

assert_eq!(
    "(1.987, 2.983)",
    format!("{}", Position { longitude: 1.987, latitude: 2.983, }),
);

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Display for !

1.26.0 · Source

impl Display for AccessError

1.4.0 · Source

impl Display for AddrParseError

Source

impl Display for blvm_consensus::smallvec::alloc::alloc::AllocError

Source

impl Display for allocator_api2::stable::alloc::AllocError

1.0.0 · Source

impl Display for Arguments<'_>

Source

impl Display for AsciiChar

Source

impl Display for Ast

Print a display representation of this Ast.

This does not preserve any of the original whitespace formatting that may have originally been present in the concrete syntax from which this Ast was generated.

This implementation uses constant stack space and heap space proportional to the size of the Ast.

1.65.0 · Source

impl Display for Backtrace

Source

impl Display for BernoulliError

Source

impl Display for BigEndian

Source

impl Display for BigInt

Source

impl Display for BigUint

Source

impl Display for BlockParseError

1.13.0 · Source

impl Display for BorrowError

1.13.0 · Source

impl Display for BorrowMutError

Source

impl Display for ByteStr

Source

impl Display for ByteString

Source

impl Display for CaseFoldError

1.34.0 · Source

impl Display for CharTryFromError

Source

impl Display for CollectionAllocErr

Source

impl Display for ConsensusError

1.9.0 · Source

impl Display for DecodeUtf16Error

1.87.0 · Source

impl Display for std::ffi::os_str::Display<'_>

1.0.0 · Source

impl Display for std::path::Display<'_>

Source

impl Display for ElligatorSwift

Source

impl Display for Errno

1.0.0 · Source

impl Display for std::io::error::Error

1.0.0 · Source

impl Display for blvm_consensus::smallvec::alloc::fmt::Error

Source

impl Display for block_buffer::Error

Source

impl Display for serde_core::de::value::Error

Source

impl Display for bitcoin_hashes::error::Error

Source

impl Display for bitcoin_hashes::hex::Error

Source

impl Display for serde_json::error::Error

Source

impl Display for secp256k1::Error

Source

impl Display for proptest::string::Error

Source

impl Display for rusty_fork::error::Error

Source

impl Display for getrandom::error::Error

Source

impl Display for rand_core::error::Error

Source

impl Display for getrandom::error::Error

Source

impl Display for regex_syntax::ast::Error

Source

impl Display for regex_syntax::error::Error

Source

impl Display for regex_syntax::hir::Error

1.60.0 · Source

impl Display for core::io::error::ErrorKind

Source

impl Display for regex_syntax::ast::ErrorKind

Source

impl Display for regex_syntax::hir::ErrorKind

1.20.0 · Source

impl Display for core::char::EscapeDebug

1.39.0 · Source

impl Display for core::ascii::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeUnicode

1.0.0 · Source

impl Display for ExitStatus

Source

impl Display for ExitStatusError

Source

impl Display for ExitStatusWrapper

1.69.0 · Source

impl Display for FromBytesUntilNulError

1.17.0 · Source

impl Display for FromBytesWithNulError

Source

impl Display for FromHexError

1.0.0 · Source

impl Display for FromUtf8Error

1.0.0 · Source

impl Display for FromUtf16Error

1.58.0 · Source

impl Display for FromVecWithNulError

1.86.0 · Source

impl Display for GetDisjointMutError

Source

impl Display for Gid

Source

impl Display for bitcoin_hashes::hash160::Hash

Source

impl Display for bitcoin_hashes::ripemd160::Hash

Source

impl Display for bitcoin_hashes::sha1::Hash

Source

impl Display for bitcoin_hashes::sha256::Hash

Source

impl Display for bitcoin_hashes::sha256d::Hash

Source

impl Display for bitcoin_hashes::siphash24::Hash

Source

impl Display for bitcoin_hashes::sha512::Hash

Source

impl Display for Hir

Print a display representation of this Hir.

The result of this is a valid regular expression pattern string.

This implementation uses constant stack space and heap space proportional to the size of the Hir.

1.34.0 · Source

impl Display for Infallible

1.7.0 · Source

impl Display for IntoStringError

Source

impl Display for InvalidBufferSize

Source

impl Display for InvalidLength

Source

impl Display for InvalidOutputSize

Source

impl Display for InvalidParityValue

1.7.0 · Source

impl Display for IpAddr

1.0.0 · Source

impl Display for Ipv4Addr

1.0.0 · Source

impl Display for Ipv6Addr

Writes an Ipv6Addr, conforming to the canonical style described by RFC 5952.

1.0.0 · Source

impl Display for JoinPathsError

1.28.0 · Source

impl Display for LayoutError

Source

impl Display for LittleEndian

1.26.0 · Source

impl Display for Location<'_>

Source

impl Display for Message

Source

impl Display for Midstate

Source

impl Display for NormalizeError

1.0.0 · Source

impl Display for NulError

Source

impl Display for Number

Source

impl Display for OutOfRangeError

1.26.0 · Source

impl Display for PanicHookInfo<'_>

1.26.0 · Source

impl Display for PanicInfo<'_>

1.81.0 · Source

impl Display for PanicMessage<'_>

Source

impl Display for ParseBigIntError

1.0.0 · Source

impl Display for ParseBoolError

1.20.0 · Source

impl Display for ParseCharError

Source

impl Display for ParseError

1.0.0 · Source

impl Display for core::num::float_parse::ParseFloatError

Source

impl Display for num_traits::ParseFloatError

1.0.0 · Source

impl Display for ParseIntError

Source

impl Display for PathPersistError

Source

impl Display for PersistedSeed

Source

impl Display for PublicKey

Source

impl Display for ReadError

Source

impl Display for Reason

1.0.0 · Source

impl Display for RecvError

1.15.0 · Source

impl Display for std::sync::mpsc::RecvTimeoutError

Source

impl Display for RngAlgorithm

Source

impl Display for SerializedSignature

Source

impl Display for secp256k1::ecdsa::Signature

Source

impl Display for secp256k1::schnorr::Signature

1.0.0 · Source

impl Display for SocketAddr

1.0.0 · Source

impl Display for SocketAddrV4

1.0.0 · Source

impl Display for SocketAddrV6

1.0.0 · Source

impl Display for String

1.7.0 · Source

impl Display for StripPrefixError

1.8.0 · Source

impl Display for SystemTimeError

Source

impl Display for TestCaseError

Source

impl Display for TestRunner

Source

impl Display for ThreadPoolBuildError

1.16.0 · Source

impl Display for ToLowercase

Source

impl Display for ToTitlecase

1.16.0 · Source

impl Display for ToUppercase

Source

impl Display for TransactionParseError

1.59.0 · Source

impl Display for TryFromCharError

1.66.0 · Source

impl Display for TryFromFloatSecsError

1.34.0 · Source

impl Display for TryFromIntError

1.35.0 · Source

impl Display for TryFromSliceError

1.89.0 · Source

impl Display for std::fs::TryLockError

1.0.0 · Source

impl Display for std::sync::mpsc::TryRecvError

1.57.0 · Source

impl Display for blvm_consensus::smallvec::alloc::collections::TryReserveError

Source

impl Display for allocator_api2::stable::raw_vec::TryReserveError

Source

impl Display for Uid

Source

impl Display for UnicodeWordError

Source

impl Display for UnorderedKeyError

1.0.0 · Source

impl Display for Utf8Error

Source

impl Display for Value

1.0.0 · Source

impl Display for VarError

Source

impl Display for VarIntError

Source

impl Display for WeightedError

Source

impl Display for WouldBlock

1.56.0 · Source

impl Display for WriterPanicked

Source

impl Display for XOnlyPublicKey

1.0.0 · Source

impl Display for bool

1.0.0 · Source

impl Display for char

Source

impl Display for dyn Expected + '_

1.0.0 · Source

impl Display for f16

1.0.0 · Source

impl Display for f32

1.0.0 · Source

impl Display for f64

1.0.0 · Source

impl Display for i8

1.0.0 · Source

impl Display for i16

1.0.0 · Source

impl Display for i32

1.0.0 · Source

impl Display for i64

1.0.0 · Source

impl Display for i128

1.0.0 · Source

impl Display for isize

1.0.0 · Source

impl Display for str

1.0.0 · Source

impl Display for u8

1.0.0 · Source

impl Display for u16

1.0.0 · Source

impl Display for u32

1.0.0 · Source

impl Display for u64

1.0.0 · Source

impl Display for u128

1.0.0 · Source

impl Display for usize

1.60.0 · Source

impl<'a> Display for EscapeAscii<'a>

1.34.0 · Source

impl<'a> Display for blvm_consensus::smallvec::alloc::str::EscapeDebug<'a>

1.34.0 · Source

impl<'a> Display for blvm_consensus::smallvec::alloc::str::EscapeDefault<'a>

1.34.0 · Source

impl<'a> Display for blvm_consensus::smallvec::alloc::str::EscapeUnicode<'a>

Source

impl<'a> Display for Unexpected<'a>

Source

impl<A, S, V> Display for ConvertError<A, S, V>
where A: Display, S: Display, V: Display,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

1.0.0 · Source

impl<B> Display for Cow<'_, B>
where B: Display + ToOwned + ?Sized, <B as ToOwned>::Owned: Display,

Source

impl<E> Display for Report<E>
where E: Error,

1.93.0 · Source

impl<F> Display for FromFn<F>
where F: Fn(&mut Formatter<'_>) -> Result<(), Error>,

Source

impl<F> Display for PersistError<F>

Source

impl<K, V, S, A> Display for OccupiedError<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,

Source

impl<L, R> Display for Either<L, R>
where L: Display, R: Display,

Source

impl<O> Display for F32<O>
where O: ByteOrder,

Source

impl<O> Display for F64<O>
where O: ByteOrder,

Source

impl<O> Display for I16<O>
where O: ByteOrder,

Source

impl<O> Display for I32<O>
where O: ByteOrder,

Source

impl<O> Display for I64<O>
where O: ByteOrder,

Source

impl<O> Display for I128<O>
where O: ByteOrder,

Source

impl<O> Display for Isize<O>
where O: ByteOrder,

Source

impl<O> Display for U16<O>
where O: ByteOrder,

Source

impl<O> Display for U32<O>
where O: ByteOrder,

Source

impl<O> Display for U64<O>
where O: ByteOrder,

Source

impl<O> Display for U128<O>
where O: ByteOrder,

Source

impl<O> Display for Usize<O>
where O: ByteOrder,

1.33.0 · Source

impl<Ptr> Display for Pin<Ptr>
where Ptr: Display,

Source

impl<Src, Dst> Display for AlignmentError<Src, Dst>
where Src: Deref, Dst: KnownLayout + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<Src, Dst> Display for SizeError<Src, Dst>
where Src: Deref, Dst: KnownLayout + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<Src, Dst> Display for ValidityError<Src, Dst>
where Dst: KnownLayout + TryFromBytes + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

1.0.0 · Source

impl<T, A> Display for Arc<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for blvm_consensus::smallvec::alloc::boxed::Box<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for allocator_api2::stable::boxed::Box<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Rc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueArc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueRc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, B> Display for zerocopy::ref::def::Ref<B, T>

1.0.0 · Source

impl<T> Display for &T
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for &mut T
where T: Display + ?Sized,

Source

impl<T> Display for CachePadded<T>
where T: Display,

Source

impl<T> Display for bitcoin_hashes::sha256t::Hash<T>
where T: Tag,

Source

impl<T> Display for Hmac<T>
where T: Hash,

Source

impl<T> Display for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

1.28.0 · Source

impl<T> Display for NonZero<T>

1.0.0 · Source

impl<T> Display for PoisonError<T>

Source

impl<T> Display for std::sync::oneshot::RecvTimeoutError<T>

Source

impl<T> Display for ReentrantLockGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for core::cell::Ref<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for RefMut<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.74.0 · Source

impl<T> Display for Saturating<T>
where T: Display,

1.0.0 · Source

impl<T> Display for SendError<T>

Source

impl<T> Display for SendTimeoutError<T>

Source

impl<T> Display for ShardedLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for ShardedLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for TestError<T>
where T: Debug,

Source

impl<T> Display for ThinBox<T>
where T: Display + ?Sized,

Source

impl<T> Display for TryFromBigIntError<T>

1.0.0 · Source

impl<T> Display for std::sync::poison::TryLockError<T>

Source

impl<T> Display for std::sync::oneshot::TryRecvError<T>

1.0.0 · Source

impl<T> Display for TrySendError<T>

Source

impl<T> Display for Unalign<T>
where T: Unaligned + Display,

1.10.0 · Source

impl<T> Display for Wrapping<T>
where T: Display,

1.0.0 · Source

impl<W> Display for IntoInnerError<W>