pub struct BlockHeader {
pub version: i64,
pub prev_block_hash: [u8; 32],
pub merkle_root: [u8; 32],
pub timestamp: u64,
pub bits: u64,
pub nonce: u64,
}Expand description
Block Header: ℋ = ℤ × ℍ × ℍ × ℕ × ℕ × ℕ
Default is only used as a placeholder when extracting the header for BIP113
tracking; the default value is never used for consensus.
Fields
version: i64prev_block_hash: [u8; 32]merkle_root: [u8; 32]timestamp: u64bits: u64nonce: u64Trait Implementations
Sourceimpl AsRef<BlockHeader> for BlockHeader
impl AsRef<BlockHeader> for BlockHeader
Sourcefn as_ref(&self) -> &BlockHeader
fn as_ref(&self) -> &BlockHeader
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for BlockHeader
impl Clone for BlockHeader
Sourcefn clone(&self) -> BlockHeader
fn clone(&self) -> BlockHeader
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlockHeader
impl Debug for BlockHeader
Sourceimpl Default for BlockHeader
impl Default for BlockHeader
Sourcefn default() -> BlockHeader
fn default() -> BlockHeader
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BlockHeader
impl<'de> Deserialize<'de> for BlockHeader
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<BlockHeader, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<BlockHeader, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for BlockHeader
impl PartialEq for BlockHeader
Sourcefn eq(&self, other: &BlockHeader) -> bool
fn eq(&self, other: &BlockHeader) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BlockHeader
impl Serialize for BlockHeader
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for BlockHeader
impl StructuralPartialEq for BlockHeader