pub struct Transaction {
pub version: u64,
pub inputs: SmallVec<[TransactionInput; 2]>,
pub outputs: SmallVec<[TransactionOutput; 2]>,
pub lock_time: u64,
}Expand description
Transaction: ๐ฏ๐ณ = โ ร โ* ร ๐ฏ* ร โ
Performance optimization: Uses SmallVec for inputs/outputs to eliminate heap allocations for the common case of 1-2 inputs/outputs (80%+ of transactions).
Fields
version: u64inputs: SmallVec<[TransactionInput; 2]>outputs: SmallVec<[TransactionOutput; 2]>lock_time: u64Trait Implementations
Sourceimpl Clone for Transaction
impl Clone for Transaction
Sourcefn clone(&self) -> Transaction
fn clone(&self) -> Transaction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Transaction
impl Debug for Transaction
Sourceimpl<'de> Deserialize<'de> for Transaction
impl<'de> Deserialize<'de> for Transaction
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Transaction, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Transaction, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for Transaction
impl PartialEq for Transaction
Sourcefn eq(&self, other: &Transaction) -> bool
fn eq(&self, other: &Transaction) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for Transaction
impl Serialize for Transaction
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for Transaction
impl StructuralPartialEq for Transaction