pub unsafe fn prefetch_read(ptr: *const i8)Expand description
Prefetch data for read access
Hints the CPU to prefetch data into cache before it’s needed. This improves performance for sequential memory access patterns.
Safety
The pointer must be valid, but it doesn’t need to be dereferenceable at the time of the call. The prefetch is a hint and may be ignored.