Reference implementations for equivalence proofs
These are safe versions of optimized functions, used to prove that optimizations are correct via formal verification.
Functions
- get_
proven_ reference - Reference (safe) implementation of get_proven This is the version we prove equivalence against